@@ -1,5 +1,5 @@
 ##############################################################################
-#    Copyright (c) 2012-2017 Russell V. Lenth                                #
+#    Copyright (c) 2012-2022 Russell V. Lenth                                #
 #                                                                            #
 #    This file is part of the emmeans package for R (*emmeans*)              #
 #                                                                            #
@@ -27,8 +27,9 @@
 
 # gam::Gam objects...
 
-# We have two args:
+# We have one args:
 #   nboot   # of bootstrap reps to get variances of smooths
+#' @exportS3Method emm_basis Gam
 emm_basis.Gam = function(object, trms, xlev, grid, nboot = 800, ...) {
     result = emm_basis.lm(object, trms, xlev, grid, ...)
     old.smooth = object$smooth
@@ -113,13 +114,24 @@ emm_basis.Gam = function(object, trms, xlev, grid, nboot = 800, ...) {
          dfargs = dfargs, misc = misc)
 }
 
+# Local utility for identifying random smooths
+.smooth.is.random = function(s) {
+    rcls = c("random.effect", "fs.interaction") ### what to look for
+    cls = c(class(s), unname(unlist(lapply(s$margin, class))))
+    any(cls %in% rcls)
+}
 
 ### for mgcv::gam objects
 ### Many thanks to Maarten Jung for help on sorting-out fixed and random effects
+#' @exportS3Method recover_data gam
 recover_data.gam = function(object, ...) {
     if (length(object$smooth) > 0) { # get rid of random terms
-        fixnm = sapply(object$smooth, function(s) {ifelse(inherits(s, "random.effect"), NA, s$term)})
-        fixnm = union(.all.vars(delete.response(object$pterms)), fixnm[!is.na(fixnm)])
+        fixnm = unlist(lapply(object$smooth, function(s) {
+                              if(.smooth.is.random(s)) ""
+                              else c(s$term, s$by)
+            }))
+        fixnm = union(.all.vars(delete.response(object$pterms)), fixnm)
+        fixnm = setdiff(fixnm, c("1", "", "NA"))
         object$terms = terms(.reformulate(fixnm, env = environment(terms(object))))
     }
     recover_data.lm(object, ...)
@@ -128,12 +140,13 @@ recover_data.gam = function(object, ...) {
 
 ### emm_basis method for mgcv::gam objects
 ### extra arg `unconditional` and `freq` as in `vcov.gam`
+#' @exportS3Method emm_basis gam          
 emm_basis.gam = function(object, trms, xlev, grid,
                          freq = FALSE, unconditional = FALSE,
                          what = c("location", "scale", "shape", "rate", "prob.gt.0"), 
                          ...) {
     if (length(object$smooth) > 0) { # get rid of random terms 
-        rand = sapply(object$smooth, function(s) {ifelse(inherits(s, "random.effect"), s$label, NA)})
+        rand = sapply(object$smooth, function(s) {ifelse(.smooth.is.random(s), s$label, NA)})
         rand = if (all(is.na(rand))) NULL else rand[!is.na(rand)]
     }
     else
@@ -201,6 +214,7 @@ emm_basis.gam = function(object, trms, xlev, grid,
 
 
 ### mgcv::gamm objects...
+#' @exportS3Method recover_data gamm
 recover_data.gamm = function(object, data = NULL, call = object$gam$call, ...) {
     gam = object$gam
     class(gam) = c("gam", "glm", "lm")
@@ -216,6 +230,7 @@ recover_data.gamm = function(object, data = NULL, call = object$gam$call, ...) {
     }
 }
 
+#' @exportS3Method emm_basis gamm         
 emm_basis.gamm = function(object, ...)
     emm_basis(object$gam, ...)
 
@@ -224,6 +239,7 @@ emm_basis.gamm = function(object, ...)
 # Support for gamlss objects
 # 'what' parameter mimics predict.gamlss
 
+#' @exportS3Method recover_data gamlss
 recover_data.gamlss = function(object, what = c("mu", "sigma", "nu", "tau"), ...) {
     fcall = object$call
     what = match.arg(what)
@@ -231,6 +247,7 @@ recover_data.gamlss = function(object, what = c("mu", "sigma", "nu", "tau"), ...
     recover_data(fcall, delete.response(trms), object$na.action, ...)
 }
 
+#' @exportS3Method emm_basis gamlss       
 emm_basis.gamlss = function(object, trms, xlev, grid, 
                             what = c("mu", "sigma", "nu", "tau"), vcov., ...) {
     what = match.arg(what)
