@@ -1,5 +1,5 @@
 ##############################################################################
-#    Copyright (c) 2012-2017 Russell V. Lenth                                #
+#    Copyright (c) 2012-2025 Russell V. Lenth                                #
 #                                                                            #
 #    This file is part of the emmeans package for R (*emmeans*)              #
 #                                                                            #
@@ -30,14 +30,15 @@
 #' @method plot emmGrid
 #' @export
 plot.emmGrid = function(x, y, type, CIs = TRUE, PIs = FALSE, comparisons = FALSE, 
-                    colors = c("black", "blue", "blue", "red"),
-                    alpha = .05, adjust = "tukey", int.adjust = "none", intervals, frequentist, ...) {
+                    colors,
+                    alpha = .05, adjust = "tukey", int.adjust = "none", intervals, ...) {
+    
     if(!missing(intervals))
         CIs = intervals
     nonlin.scale = FALSE
     if(!missing(type)) {
         # If we say type = "scale", set it to "response" and set a flag
-        if (nonlin.scale <- (pmatch(type, "scale", 0) == 1)) 
+        if (nonlin.scale <- (type %.pin% "scale"))  ##(pmatch(type, "scale", 0) == 1)) 
             type = "response"
         object = update(x, predict.type = type, ..., silent = TRUE)
     }
@@ -55,8 +56,9 @@ plot.emmGrid = function(x, y, type, CIs = TRUE, PIs = FALSE, comparisons = FALSE
             int.adjust = "none"
     }
     
+    frequentist = (\(frequentist = FALSE, ...) frequentist)(...)
     # we will do everything on link scale and back-transform later in .plot.srg...
-    summ = summary(object, infer = c(TRUE, FALSE), adjust = int.adjust, frequentist = frequentist, type = "lp", ...)
+    summ = summary(object, infer = c(TRUE, FALSE), adjust = int.adjust, type = "lp", ...)
     if (is.null(attr(summ, "pri.vars"))) { ## new ref_grid - use all factors w/ > 1 level
         pv = names(x@levels)
         len = sapply(x@levels, length)
@@ -66,15 +68,17 @@ plot.emmGrid = function(x, y, type, CIs = TRUE, PIs = FALSE, comparisons = FALSE
     }
     if (PIs) {
         prd = predict(object, interval = "pred", frequentist = frequentist, type = "lp", ...)
-        summ$lpl = prd$lower.PL
-        summ$upl = prd$upper.PL
+        if (PIs <- !is.null(prd)) {
+            summ$lpl = prd$lower.PL
+            summ$upl = prd$upper.PL
+        }
     }
     
     estName = attr(summ, "estName")
     extra = NULL
     bayes = 
     if(comparisons) {
-        if ((!is.na(object@post.beta[1])) && (missing(frequentist) || !frequentist))
+        if ((!is.na(object@post.beta[1])) && (!frequentist))
             stop("Comparison intervals are not implemented for Bayesian analyses")
         extra = object
         extra@misc$comp.alpha = alpha
@@ -122,8 +126,9 @@ plot.emmGrid = function(x, y, type, CIs = TRUE, PIs = FALSE, comparisons = FALSE
 #' @param CIs Logical value. If \code{TRUE}, confidence intervals are
 #'   plotted for each estimate.
 #' @param PIs Logical value. If \code{TRUE}, prediction intervals are
-#'   plotted for each estimate. If \code{objecct} is a Bayesian model,
-#'   this requires \code{frequentist = TRUE} and \code{sigma =} (some value).
+#'   plotted for each estimate. If \code{object} is a Bayesian model,
+#'   this requires the \code{...} arguments to include
+#'   \code{frequentist = TRUE} and \code{sigma =} (some value).
 #'   Note that the \code{PIs} option is \emph{not} available with
 #'   \code{summary_emm} objects -- only for \code{emmGrid} objects.
 #'   Also, prediction intervals are not available
@@ -133,23 +138,25 @@ plot.emmGrid = function(x, y, type, CIs = TRUE, PIs = FALSE, comparisons = FALSE
 #'   overlap reflects as much as possible the significance of the comparison of
 #'   the two estimates. (A warning is issued if this can't be done.)
 #'   Note that comparison arrows are not available with `summary_emm` objects.
-#' @param colors Character vector of color names to use for estimates, CIs, PIs, 
-#'   and comparison arrows, respectively. CIs and PIs are rendered with some
-#'   transparency, and colors are recycled if the length is less than four;
-#'   so all plot elements are visible even if a single color is specified. 
+#' @param colors Optional character vector of colors to use for estimates, CIs, PIs, 
+#'   and comparison arrows, respectively. If missing, these are derived from
+#'   \code{ink}, \code{paper}, and \code{accent} in the theme's \code{geom} element.
+#'   \code{ink} is used for the estimates, \code{accent} is used for comparison arrows,
+#'   and a contrasting color to \code{accent} is blended with \code{paper} for
+#'   the intervals. 
+#'   If just one color is given, estimates and intervals are made from
+#'   various blends of that color and \code{paper}, and \code{accent}
+#'   color is used for comparison arrows.
 #' @param alpha The significance level to use in constructing comparison arrows
 #' @param adjust Character value: Multiplicity adjustment method for comparison arrows \emph{only}.
 #' @param int.adjust Character value: Multiplicity adjustment method for the plotted confidence intervals \emph{only}.
 #' @param intervals If specified, it is used to set \code{CIs}. This is the previous
 #'   argument name for \code{CIs} and is provided for backward compatibility.
-#' @param frequentist Logical value. If there is a posterior MCMC sample and 
-#'   \code{frequentist} is non-missing and TRUE, a frequentist summary is used for
-#'   obtaining the plot data, rather than the posterior point estimate and HPD
-#'   intervals. This argument is ignored when it is not a Bayesian model.
 #' @param plotit Logical value. If \code{TRUE}, a graphical object is returned;
 #'   if \code{FALSE}, a data.frame is returned containing all the values
 #'   used to construct the plot.
 #' @param ... Additional arguments passed to \code{\link{update.emmGrid}}, 
+#'   \code{\link{summary.emmGrid}},
 #'   \code{\link{predict.emmGrid}}, or
 #'   \code{\link[lattice:xyplot]{dotplot}}
 #'
@@ -185,7 +192,13 @@ plot.emmGrid = function(x, y, type, CIs = TRUE, PIs = FALSE, comparisons = FALSE
 #' internal \code{adjust} setting saved in \code{pairs(x)} and \code{x} 
 #' respectively (see \code{\link{update.emmGrid}}).
 #' 
+#' @note In order to play nice with the plotting functions,
+#' any variable names that are not syntactically correct (e.g., contain spaces)
+#' are altered using \code{\link{make.names}}.
+#' 
 #' @importFrom graphics plot
+#' 
+
 #' @method plot summary_emm
 #' @export
 #'
@@ -193,8 +206,14 @@ plot.emmGrid = function(x, y, type, CIs = TRUE, PIs = FALSE, comparisons = FALSE
 #' warp.lm <- lm(breaks ~ wool * tension, data = warpbreaks)
 #' warp.emm <- emmeans(warp.lm, ~ tension | wool)
 #' plot(warp.emm)
-#' plot(warp.emm, by = NULL, comparisons = TRUE, adjust = "mvt", 
-#'      horizontal = FALSE, colors = "darkgreen")
+#' 
+#' plot(warp.emm, PIs = TRUE, comparisons = TRUE)
+#' 
+#' with_emm_options(gg.theme = ggplot2::theme_dark(), 
+#'     plot(warp.emm, PIs = TRUE, comparisons = TRUE))
+#' 
+#' plot(warp.emm, by = NULL, comparisons = TRUE, adjust = "none", 
+#'      horizontal = FALSE, colors = "blue")
 #' 
 #' ### Using a transformed scale
 #' pigs.lm <- lm(log(conc + 2) ~ source * factor(percent), data = pigs)
@@ -208,7 +227,7 @@ plot.emmGrid = function(x, y, type, CIs = TRUE, PIs = FALSE, comparisons = FALSE
 #' plot(pigs.ci, scale = scales::log10_trans())
 plot.summary_emm = function(x, y, horizontal = TRUE, CIs = TRUE,
                             xlab, ylab, layout, scale = NULL,
-                            colors = c("black", "blue", "blue", "red"), intervals, 
+                            colors, intervals, 
                             plotit = TRUE, ...) {
     if(!missing(intervals))
         CIs = intervals
@@ -219,6 +238,7 @@ plot.summary_emm = function(x, y, horizontal = TRUE, CIs = TRUE,
 }
 
 # Workhorse for plot.summary_emm
+#' @importFrom grDevices col2rgb hcl rgb rgb2hsv
 .plot.srg = function(x, y, 
                      horizontal = TRUE, xlab, ylab, layout, colors,
                      engine = get_emm_option("graphics.engine"),
@@ -246,6 +266,9 @@ plot.summary_emm = function(x, y, horizontal = TRUE, CIs = TRUE,
         ucl = summ[[clNames[2]]]
     }
     
+    # ensure all names are syntactically valid
+    summ = .validate.names(summ)
+    
     if (engine == "lattice") { # ---------- lattice-specific stuff ----------
         
         # Panel functions...
@@ -286,7 +309,7 @@ plot.summary_emm = function(x, y, horizontal = TRUE, CIs = TRUE,
                     s = (x < max(x))
                     lattice::panel.arrows(rcmpl[s], y[s], x[s], y[s], length = .5, unit = "char", code = 1, col = "red", type = "closed", fill="red")
                 }
-            }
+            } 
             else {
                 lattice::panel.abline(v = unique(x), col = col.line, lty = lty, lwd = lwd)
                 if(CIs)
@@ -341,6 +364,7 @@ plot.summary_emm = function(x, y, horizontal = TRUE, CIs = TRUE,
         alpha = extra@misc$comp.alpha
         adjust = extra@misc$comp.adjust
         psumm = suppressMessages(confint(pairs(extra), level = 1 - alpha, type = "lp", adjust = adjust))
+        psumm = .validate.names(psumm)
         k = ncol(psumm)
         del = (psumm[[k]] - psumm[[k-1]]) / 4 # half the halfwidth, on lp scale
         diff = psumm[[attr(psumm, "estName")]]
@@ -467,14 +491,18 @@ plot.summary_emm = function(x, y, horizontal = TRUE, CIs = TRUE,
     
     facName = paste(priv, collapse=":")
     
-    if(length(colors) < 4)
-        colors = rep(colors, 4)
-    dot.col = colors[1]
-    CI.col = colors[2]
-    PI.col = colors[3]
-    comp.col = colors[4]
+    # private lil fcn to mix colors with white
+    mix_col = function(col1, col2, frac) {
+        x = grDevices::colorRamp(c(col1, col2))(frac) / 255
+        rgb(x[1], x[2], x[3], 1)
+    }
     
     if (engine == "lattice") {
+        if(missing(colors))
+            colors = c("black", mix_col("white", "blue", .35), mix_col("white", "blue", .20), "red")
+        if(length(colors) == 1)
+            colors = c(colors, mix_col("white", colors, .35), mix_col("white", colors, .20), "red")
+        
         if (missing(layout)) {
             layout = c(1, length(ubv))
             if(!horizontal) 
@@ -502,44 +530,65 @@ plot.summary_emm = function(x, y, horizontal = TRUE, CIs = TRUE,
         }
     } # --- end lattice plot
     else {  ## ggplot method
+        thm = theme_emm()
+        
+        if(missing(colors) && is.numeric(thopt <- get_emm_option("gg.theme")) && thopt == 1)
+            colors = c("black", mix_col("white", "blue", .35), mix_col("white", "blue", .20), "red")
+        
+        if(missing(colors) || (length(colors) == 1)) {
+            dot.col = ifelse(missing(colors), thm$geom@ink, colors)
+            paper = thm$geom@paper
+            if(missing(colors)) {   # derive a contrasting color to 'accent' color
+                xxx = (rgb2hsv(col2rgb(thm$geom@accent))[1] + 0.54) %% 1
+                clr = hcl(xxx * 360, 80, 50)
+            }
+            else
+                clr = dot.col
+            colors = c(dot.col, mix_col(paper, clr, 0.25), mix_col(paper, clr, 0.15), thm$geom@accent)
+        }
+        dot.col = colors[1]
+        CI.col = colors[2]
+        PI.col = colors[3]
+        comp.col = colors[4]
+        
         summ$lcl = lcl
         summ$ucl = ucl
 
         # construct horizontal plot - flip coords later if necessary
-        grobj = ggplot2::ggplot(summ, ggplot2::aes_(x = ~the.emmean, y = ~pri.fac)) +
+        grobj = ggplot2::ggplot(summ, ggplot2::aes(x = .data$the.emmean, y = .data$pri.fac)) +
             ggplot2::geom_point(color = CI.col, alpha = .0) 
             # invisible points to get grouping order right
         if (PIs) 
-            grobj = grobj + ggplot2::geom_segment(ggplot2::aes_(x = ~lpl, xend = ~upl, 
-                                y = ~pri.fac, yend = ~pri.fac), 
-                                color = PI.col, lwd = 2.5, alpha = .15)
+            grobj = grobj + ggplot2::geom_segment(ggplot2::aes(x = .data$lpl, xend = .data$upl, 
+                                y = .data$pri.fac, yend = .data$pri.fac), 
+                                color = PI.col, lwd = 2.5)
         if (CIs) 
-            grobj = grobj + ggplot2::geom_segment(ggplot2::aes_(x = ~lcl, xend = ~ucl, 
-                                y = ~pri.fac, yend = ~pri.fac), 
-                                color = CI.col, lwd = 4, alpha = .25)
+            grobj = grobj + ggplot2::geom_segment(ggplot2::aes(x = .data$lcl, xend = .data$ucl, 
+                                y = .data$pri.fac, yend = .data$pri.fac), 
+                                color = CI.col, lwd = 4)
 
         if (!is.null(extra)) {
             grobj = grobj + 
-                ggplot2::geom_segment(ggplot2::aes_(x = ~the.emmean, 
-                        xend = ~lcmpl, y = ~pri.fac, yend = ~pri.fac), 
-                        arrow = ggplot2::arrow(length = ggplot2::unit(.07, "inches"), 
+                ggplot2::geom_segment(ggplot2::aes(x = .data$the.emmean, linewidth = 1,
+                        xend = .data$lcmpl, y = .data$pri.fac, yend = .data$pri.fac), linewidth = 0.9,
+                        arrow = ggplot2::arrow(length = ggplot2::unit(.07, "inches"),  
                             type = "closed"), color = comp.col, 
                         data = summ[!is.na(summ$lcmpl), ]) +
-                ggplot2::geom_segment(ggplot2::aes_(x = ~the.emmean, 
-                    xend = ~rcmpl, y = ~pri.fac, yend = ~pri.fac), 
+                ggplot2::geom_segment(ggplot2::aes(x = .data$the.emmean, 
+                    xend = .data$rcmpl, y = .data$pri.fac, yend = .data$pri.fac), linewidth = 0.9,
                     arrow = ggplot2::arrow(length = ggplot2::unit(.07, "inches"), 
                             type = "closed"), color = comp.col,
                     data = summ[!is.na(summ$rcmpl), ])
         }
         if (length(byv) > 0)
             grobj = grobj + ggplot2::facet_grid(as.formula(paste(paste(byv, collapse = "+"), " ~ .")), 
-                                       labeller = "label_both")
-        grobj = grobj + ggplot2::geom_point(color = dot.col, size = 2)
+                                                labeller = "label_both")
+        grobj = grobj + ggplot2::geom_point(color = dot.col, size = 4, shape = 18)
         
         if(!is.null(scale)) {
             args = list(...)
-            pass = pmatch(names(args), names(as.list(args(ggplot2::scale_x_continuous))))
-            args = c(list(trans = scale), args[which(!is.na(pass))])
+            pass = (names(args) %.pin% names(as.list(args(ggplot2::scale_x_continuous))))
+            args = c(list(trans = scale), args[pass])
             grobj = grobj + do.call(ggplot2::scale_x_continuous, args)
         }
             
@@ -549,6 +598,6 @@ plot.summary_emm = function(x, y, horizontal = TRUE, CIs = TRUE,
         if(!horizontal)
             grobj = grobj + ggplot2::coord_flip()
         
-        grobj + ggplot2::labs(x = xlab, y = ylab)
+        grobj + ggplot2::labs(x = xlab, y = ylab) + thm
     }
 }
