@@ -28,7 +28,7 @@
 #' 
 #' Usually, you need to provide either \code{object}; or
 #' \code{formula}, \code{coef}, \code{vcov}, \code{data}, and perhaps other
-#' parameters. It is usually fairly straightforward to figure out how to get
+#' parameters. It is often fairly straightforward to figure out how to get
 #' these from the model \code{object}; see the documentation for the model class that
 #' was fitted. Sometimes one or more of these quantities contains extra parameters,
 #' and if so, you may need to subset them to make everything conformable. For a given \code{formula} and \code{data},
@@ -38,24 +38,17 @@
 #' to be a matrix with these row names, and \code{vcov} to have as many rows and columns as
 #' the total number of elements of \code{coef}.)
 #' 
-#' If your model object follows fairly closely the conventions of an \code{\link[stats]{lm}}
-#' or \code{\link[stats]{glm}}object, you may be able to get by providing the model as \code{object},
-#' and perhaps some other parameters to override the defaults.
-#' When \code{object} is specified, it is used as detailed below to try to obtain the 
-#' other arguments. The user should ensure that the defaults
-#' shown below do indeed work. 
-#' The default values for the arguments are as follows:
-#' \itemize{
-#'   \item{\code{formula}: \code{formula(object)}}
-#'   \item{\code{data}: \code{recover_data.lm(object)} is tried, and if an error is thrown,
-#'     we also check \code{object$data}.}
-#'   \item{\code{coef}: \code{coef(object)}}
-#'   \item{\code{vcov}: \code{vcov(object)}}
-#'   \item{\code{df}: Set to \code{Inf} if not available in \code{df.residual(object)}}
-#'   \item{\code{mcmc}: \code{object$sample}}
-#'   \item{\code{subset}: \code{NULL} (so that all observations in \code{data} are used)}
-#'   \item{\code{contrasts}: \code{object$contrasts}}
-#' }
+#' If \code{object} is specified, this function serves as a generic for dispatching
+#' a method for \code{object}'s class. See the arguments for \code{qdrg.default} to
+#' see how the arguments are determined by default. For many \code{lm}- or \code{glm}-like
+#' models, it may suffice override just one or two of these
+#' defaults. The possibility of a custom \code{qdrg} method also provides a
+#' minimal way for package developers to provide \pkg{emmeans} support: it doesn't
+#' allow directly applying \code{emmeans()} on the model, but at least the user
+#' can obtain a reference grid, and then go from there. Note that when using a `qdrg` 
+#' method, it is best for the user to specify `object =` explicitly in the
+#' call, since `object` is not the first argument of `qdrg()`. However, if the
+#' first argument is not a formula, the function is retried with it as \code{object}.
 #' 
 #' The functions \code{\link{qdrg}} and \code{emmobj} are close cousins, in that
 #' they both produce \code{emmGrid} objects. When starting with summary
@@ -89,7 +82,9 @@
 #'     For this to work, we expect
 #'     the first \code{ordinal$dim - 1} elements of \code{coef} to be the
 #'     estimated threshold parameters, followed by the coefficients for the
-#'     linear predictor.
+#'     linear predictor. Also, if \code{mode} requires back-transforming (e.g.,
+#'     \code{"prob"} or \code{"mean.class"}), the user may need to supply the \code{link}
+#'     for it to work correctly.
 #' @param ... Optional arguments passed to \code{\link{ref_grid}}
 #'
 #' @return An \code{emmGrid} object constructed from the arguments
@@ -127,38 +122,26 @@
 #'
 qdrg = function(formula, data, coef, vcov, df, mcmc, object,
                 subset, weights, contrasts, link, qr, ordinal, ...) {
-    # back-compatible access to old ordinal.dim arg...
-    od = (\(ordinal, ordinal.dim = NULL, ...) {
-        if(!missing(ordinal) && is.numeric(ordinal)) ordinal.dim = ordinal
-        ordinal.dim
-    })(ordinal, ...)
-    if(!is.null(od)) ordinal = list(dim = od, mode = "latent")
     
-    result = match.call(expand.dots = FALSE)
     if (!missing(object)) {
-        if (missing(formula)) 
-            result$formula = stats::formula(object)
-        if (missing(data)) {
-            data = try(recover_data.lm(object), silent = TRUE)
-            if(inherits(data, "try-error"))
-                data = object$data
-            if (is.null(data)) data = parent.frame()
-            result$data = data
-        }
-        if (missing(coef)) 
-            result$coef = stats::coef(object)
-        if (missing(mcmc)) 
-            result$mcmc = object$sample
-        if (missing(vcov)) 
-            result$vcov = stats::vcov(object)
-        if(missing(df))
-            result$df = df.residual(object)
-        if(missing(contrasts)) 
-            contrasts = object$contrasts
-        if(any(is.na(result$coef)))
-            result$qr = object$qr
+        UseMethod("qdrg", object = object)
     }
-    else { # missing(object) == TRUE
+    else { 
+        if(!inherits(formula, "formula")) {
+            cl = match.call()
+            cl$object = formula
+            cl$formula = NULL
+            ### message("Retrying with first argument taken as 'object'...")
+            return(eval(cl))
+        }
+        # back-compatible access to old ordinal.dim arg...
+        od = (\(ordinal, ordinal.dim = NULL, ...) {
+            if(!missing(ordinal) && is.numeric(ordinal)) ordinal.dim = ordinal
+            ordinal.dim
+        })(ordinal, ...)
+        if(!is.null(od)) ordinal = list(dim = od, mode = "latent")
+        
+        result = match.call()
         if(missing(formula))
             stop("When 'object' is missing, must at least provide 'formula'")
         result$formula = formula
@@ -171,31 +154,64 @@ qdrg = function(formula, data, coef, vcov, df, mcmc, object,
         if(!missing(df)) result$df = df
         if(missing(contrasts))
             contrasts = attr(model.matrix(result$formula, data = data), "contrasts")
+        
+        if(!missing(df)) result$df = df
+        if(is.null(result$df))
+            result$df = Inf
+        if(!missing(mcmc)) result$mcmc = mcmc
+        if(!missing(subset)) result$subset = subset
+        if(!missing(weights)) result$weights = weights
+        if(!missing(contrasts)) result$contrasts = contrasts
+        if(!missing(link)) result$link = link
+        if(!missing(qr) && any(is.na(result$coef))) result$qr = qr
+        if(!missing(ordinal)) result$ordinal = ordinal
+        
+        # make sure "formula" exists, has a LHS and is is 2nd element so that 
+        # response transformation can be found
+        if (is.null(result$formula))
+            stop("No formula; cannot construct a reference grid")
+        if(length(result$formula) < 3)
+            result$formula = update.formula(result$formula, response ~ .)
+        fpos = grep("formula", names(result))[1]
+        result = result[c(1, fpos, seq_along(result)[-c(1, fpos)])]
+        
+        class(result) = c("qdrg", "call")
+        ref_grid(result, ...)
     }
-    if(!missing(df)) result$df = df
-    if(is.null(result$df))
-        result$df = Inf
-    if(!missing(mcmc)) result$mcmc = mcmc
-    if(!missing(subset)) result$subset = subset
-    if(!missing(weights)) result$weights = weights
-    if(!missing(contrasts)) result$contrasts = contrasts
-    if(!missing(link)) result$link = link
-    if(!missing(qr) && any(is.na(result$coef))) result$qr = qr
-    if(!missing(ordinal)) result$ordinal = ordinal
-    
-    # make sure "formula" exists, has a LHS and is is 2nd element so that 
-    # response transformation can be found
-    if (is.null(result$formula))
-        stop("No formula; cannot construct a reference grid")
-    if(length(result$formula) < 3)
-        result$formula = update.formula(result$formula, response ~ .)
-    fpos = grep("formula", names(result))[1]
-    result = result[c(1, fpos, seq_along(result)[-c(1, fpos)])]
-
-    class(result) = c("qdrg", "call")
-    ref_grid(result, ...)
 }
 
+#' @rdname qdrg
+#' @exportS3Method qdrg default
+qdrg.default = function(formula = stats::formula(object), 
+                        data = try(recover_data.lm(object), silent = TRUE), 
+                        coef = stats::coef(object),
+                        vcov = stats::vcov(object), 
+                        df = stats::df.residual(object), 
+                        mcmc, 
+                        object,
+                        subset, 
+                        weights = stats::weights(object), 
+                        contrasts = object$contrasts, 
+                        link = ifelse(!is.null(lnk<-object$family$link), lnk, object$link),
+                        qr = object$qr, 
+                        ordinal, 
+                        ...) 
+{
+    
+    if(inherits(data, "try-error")) {
+        if(is.null(data <- object$data))
+            stop("Unable to recover data. You must specify it explicitly in the 'data' argument.")
+    }
+    if(missing(mcmc)) mcmc = NULL   # for some weird reason, this is needed
+    if(missing(subset)) subset = NULL
+    if(missing(ordinal)) ordinal = NULL
+    qdrg(formula = formula, data = data, coef = coef, vcov = vcov, df = df, mcmc = mcmc,
+         subset = subset, weights = weights, contrasts = contrasts, link = link,
+         qr = qr, ordinal = ordinal, ...)
+}
+
+
+
 #' @exportS3Method recover_data qdrg
 recover_data.qdrg = function(object, ...) {
     recover_data.call(object, delete.response(terms(object$formula)), object$na.action, ...)
